@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1999, 2018, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -28,6 +28,7 @@ package java.lang;
 import java.io.PrintStream;
 import java.util.Arrays;
 import java.util.List;
+import java.util.Map;
 import java.util.Optional;
 
 class VersionProps {
@@ -36,22 +37,25 @@ class VersionProps {
         "openjdk";
 
     private static final String java_version =
-        "10.0.2";
+        "13.0.2";
 
     private static final String java_version_date =
-        "2018-07-17";
+        "2020-01-14";
 
     private static final String java_runtime_name =
         "OpenJDK Runtime Environment";
 
     private static final String java_runtime_version =
-        "10.0.2+13";
+        "13.0.2+8";
 
     private static final String VERSION_NUMBER =
-        "10.0.2";
+        "13.0.2";
+
+    private static final String VERSION_SPECIFICATION =
+        "13";
 
     private static final String VERSION_BUILD =
-        "13";
+        "8";
 
     private static final String VERSION_PRE =
         "";
@@ -62,24 +66,47 @@ class VersionProps {
     private static final boolean isLTS =
         "".startsWith("LTS");
 
+    private static final String CLASSFILE_MAJOR_MINOR =
+        "57.0";
+
     private static final String VENDOR_VERSION_STRING =
-        "18.3";
+        "";
 
     private static final String vendor_version =
-        (VENDOR_VERSION_STRING.length() > 0
+        (!VENDOR_VERSION_STRING.isEmpty()
          ? " " + VENDOR_VERSION_STRING : "");
 
-    static {
-        init();
-    }
+    private static final String VENDOR =
+        "Oracle Corporation";
 
-    public static void init() {
-        System.setProperty("java.version", java_version);
-        System.setProperty("java.version.date", java_version_date);
-        System.setProperty("java.runtime.version", java_runtime_version);
-        System.setProperty("java.runtime.name", java_runtime_name);
-        if (VENDOR_VERSION_STRING.length() > 0)
-            System.setProperty("java.vendor.version", VENDOR_VERSION_STRING);
+    private static final String VENDOR_URL =
+        "https://java.oracle.com/";
+
+    private static final String VENDOR_URL_BUG =
+        "https://bugreport.java.com/bugreport/";
+
+    /**
+     * Initialize system properties using build provided values.
+     *
+     * @param props Map instance in which to insert the properties
+     */
+    public static void init(Map<String, String> props) {
+        props.put("java.version", java_version);
+        props.put("java.version.date", java_version_date);
+        props.put("java.runtime.version", java_runtime_version);
+        props.put("java.runtime.name", java_runtime_name);
+        if (!VENDOR_VERSION_STRING.isEmpty())
+            props.put("java.vendor.version", VENDOR_VERSION_STRING);
+
+        props.put("java.class.version", CLASSFILE_MAJOR_MINOR);
+
+        props.put("java.specification.version", VERSION_SPECIFICATION);
+        props.put("java.specification.name", "Java Platform API Specification");
+        props.put("java.specification.vendor", "Oracle Corporation");
+
+        props.put("java.vendor", VENDOR);
+        props.put("java.vendor.url", VENDOR_URL);
+        props.put("java.vendor.url.bug", VENDOR_URL_BUG);
     }
 
     private static int parseVersionNumber(String version, int prevIndex, int index) {
@@ -166,15 +193,8 @@ class VersionProps {
      * Print version info.
      */
     private static void print(boolean err, boolean newln) {
-        boolean isHeadless = false;
         PrintStream ps = err ? System.err : System.out;
 
-        /* Report that we're running headless if the property is true */
-        String headless = System.getProperty("java.awt.headless");
-        if ( (headless != null) && (headless.equalsIgnoreCase("true")) ) {
-            isHeadless = true;
-        }
-
         /* First line: platform version. */
         if (err) {
             ps.println(launcher_name + " version \"" + java_version + "\""
